@@ -152,8 +152,8 @@ sub accepts {
         return 0;
     }
 
-    my @have_keys  = sort keys $value->%*;
-    my @want_keys  = sort keys $self->{pattern}->%*;
+    my @have_keys  = sort keys %$value;
+    my @want_keys  = sort keys %{$self->{pattern}};
     my %want_keys  = map { $_ => 1 } @want_keys;
     my %have_keys  = map { $_ => 1 } @have_keys;
     my @unexpected = grep { !$want_keys{$_} } @have_keys;
@@ -202,7 +202,7 @@ package Mojolicious::Plugin::InputValidation;
 use Mojo::Base 'Mojolicious::Plugin';
 no strict 'subs';
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Mojo::Util 'monkey_patch';
 
